(define-singleton-type type-name var-name & [predicate-name])Defines a record type without fields. Instead of a constructor, the single value of this type is bound to var-name.
Defines a record type without fields. Instead of a constructor, the single value of this type is bound to `var-name`.
(record-type v)Returns the record type of the given record value.
(define-record-type Foo foo? (make-foo a))
(= Foo (record-type (make-foo :b)))
Returns the record type of the given record value. ``` (define-record-type Foo foo? (make-foo a)) (= Foo (record-type (make-foo :b))) ```
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |